function [ N ] = Goodman( Sa, Sm, Se, Sut )
%
%  This routine computes the modified Goodman safety factor
%
%    Sa = the alternating stress
%    Sm = the mean stress
%    Se = the endurance strength
%    Sut = the ultimate tensile strength
%
N = 1 / (Sa / Se + Sm / Sut);

end

